@@ -2,10 +2,13 @@
 
 __author__ = """Daniel Böckenhoff"""
 __email__ = "dboe@ipp.mpg.de"
-__version__ = "0.6.2"
+__version__ = "0.6.4"
 
 from . import plotting
 from . import log  # NOQA
 from . import path  # NOQA
+from . import process  # NOQA
+from . import pattern  # NOQA
+from . import polymorphism  # NOQA
 
 plotting.use("matplotlib")
